## To Do


## Doing


## Done

- usb-reporter
- usb-monitor
- mode switching
    > message sent to telegram to employ defensive tactics
- temp sensor
- lock screen
- features togglable with buttons
- allow TOKEN to be in state
- systemd user service
- only allow messages from CHAT_ID
- split up cli file
- add a programs list cmd
